@@ -5,8 +5,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef PAGESORTMODEL_H
-#define PAGESORTMODEL_H
+#pragma once
 
 #include <QAbstractProxyModel>
 
@@ -46,5 +45,3 @@ private:
     QVector<bool> m_hiddenProxy;
     QVector<bool> m_removeFiles;
 };
-
-#endif
