@@ -4,8 +4,7 @@
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
-#ifndef COLUMNDISPLAYMODEL_H
-#define COLUMNDISPLAYMODEL_H
+#pragma once
 
 #include <QIdentityProxyModel>
 
@@ -20,6 +19,7 @@ public:
     enum Roles {
         DisplayStyleRole = Qt::UserRole + 99,
     };
+    Q_ENUM(Roles)
 
     explicit ColumnDisplayModel(QObject *parent = nullptr);
 
@@ -48,5 +48,3 @@ private:
     QString m_idRole = QStringLiteral("id");
     mutable int m_idRoleNumber = -1;
 };
-
-#endif // COLUMNDISPLAYMODEL_H
